@@ -1,8 +1,7 @@
 /* exported RoomList RoomListHeader RoomRow */
 
-const { Gdk, Gio, GLib, GObject, Gtk } = imports.gi;
+const { Gdk, Gio, GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
 const Mainloop = imports.mainloop;
-const Tp = imports.gi.TelepathyGLib;
 
 const { AccountsMonitor } = imports.accountsMonitor;
 const { RoomManager } = imports.roomManager;
@@ -185,7 +184,7 @@ var RoomRow = GObject.registerClass({
             let menu = new Gio.Menu();
             let isRoom = this._room.type == Tp.HandleType.ROOM;
             menu.append(isRoom ? _("Leave chatroom") : _("End conversation"),
-                        'app.leave-room(("%s", ""))'.format(this._room.id));
+                        `app.leave-room(("${this._room.id}", ""))`);
 
             this._popover = Gtk.Popover.new_from_model(this, menu);
             this._popoverVisibleChangedId =
@@ -361,12 +360,12 @@ var RoomListHeader = GObject.registerClass({
                server address, e.g. "GNOME (irc.gnome.org)" */
             let fullTitle = _("%s (%s)").format(accountName, server);
             this._popoverTitle.label = (accountName == server) ? accountName : fullTitle;
-            this._popoverStatus.label = '<sup>' + this._getStatusLabel() + '</sup>';
+            this._popoverStatus.label = `<sup>${this._getStatusLabel()}</sup>`;
         } else {
             let styleContext = this._popoverStatus.get_style_context();
             styleContext.remove_class('dim-label');
 
-            this._popoverTitle.label = '<b>' + _("Connection Problem") + '</b>';
+            this._popoverTitle.label = `<b>${_("Connection Problem")}</b>`;
             this._popoverStatus.label = this._getErrorLabel();
         }
     }
